hyperspy.misc.machine_learning package
======================================

Submodules
----------

hyperspy.misc.machine_learning.import_sklearn module
----------------------------------------------------

.. automodule:: hyperspy.misc.machine_learning.import_sklearn
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy.misc.machine_learning.orthomax module
----------------------------------------------

.. automodule:: hyperspy.misc.machine_learning.orthomax
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy.misc.machine_learning.tools module
-------------------------------------------

.. automodule:: hyperspy.misc.machine_learning.tools
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: hyperspy.misc.machine_learning
    :members:
    :undoc-members:
    :show-inheritance:
